#!perl -T

use Test::More tests => 1;

BEGIN {
	use_ok( 'Quiz::Flashcards::Sets::Katakana::Romaji_Simple' );
}

diag( "Testing Quiz::Flashcards::Sets::Katakana::Romaji_Simple $Quiz::Flashcards::Sets::Katakana::Romaji_Simple::VERSION, Perl $], $^X" );
